using Microsoft.AspNetCore.Mvc.Rendering;
using WorkFlowCheck.Common.DTO;

namespace WorkFlowCheck.Web.Services.Interfaces
{
    public interface IBaseStockService
    {

        Task<CheckPointDTO> GetCheckPoint(int id);
        Task<bool> DeleteCheckpoint(int id);
        Task<List<CheckPointDTO>> GetAllCheckPoints();
        Task<ApiResponseDTO<CheckPointDTO>> UpdateCheckPoint(CheckPointDTO checkPointDTO);


        Task<EquipmentDTO> GetEquipment(int id);
        Task<bool> EquipmentLocation(int id);
        Task<List<EquipmentDTO>> GetAllEquipments();
        Task<ApiResponseDTO<EquipmentDTO>> UpdateEquipment(EquipmentDTO equipmentDTO);

        Task<LocationDTO> GetLocation(int id);
        Task<bool> DeleteLocation(int id);
        Task<List<LocationDTO>> GetAllLocations();
        Task<ApiResponseDTO<LocationDTO>> UpdateLocation(LocationDTO LocationDTO);

        Task<List<NumberGeneratorTemplateDTO>> GetNumbergenerators();
    }
}
